# eric7.PluginManager

Package containing the code for the Plugin Manager and related parts.

### Modules

PluginDetailsDialog | Module implementing the Plugin Details Dialog.
PluginExceptions | Module implementing the exceptions raised by the plugin system.
PluginInfoDialog | Module implementing the Plugin Info Dialog.
PluginInstallDialog | Module implementing the Plugin installation dialog.
PluginManager | Module implementing the Plugin Manager.
PluginRepositoryDialog | Module implementing a dialog showing the available plugins.
PluginRepositoryReader | Module to read the plug-in repository contents file.
PluginUninstallDialog | Module implementing a dialog for plugin deinstallation.
PluginUtilities | Module implementing common utility functions needed for plugin management.